@@ -77,8 +77,6 @@ MonitorsGround::MonitorsGround(int activateHeight, QWidget *parent)
     m_effectiveTimer->setInterval(m_nEffectiveTime*1000);
     m_effectiveTimer->setSingleShot(true);
     connect(m_effectiveTimer, &QTimer::timeout, this, [=]() {
-        m_nEffectiveTime = 2;
-        m_effectiveTimer->setInterval(m_nEffectiveTime*1000);
         Q_EMIT setEffectiveReminderVisible(false, m_nEffectiveTime);
         for (auto mon : m_model->monitorList()) {
             disconnect(mon, &Monitor::geometryChanged, this, &MonitorsGround::onGeometryChanged);
@@ -141,7 +139,7 @@ void MonitorsGround::setModel(DisplayModel *model, Monitor *moni)
     QTimer::singleShot(1, this, [=](){
         if (!m_isSingleDisplay) {
             updateScale();
-        }
+        }    
         resetMonitorsView();
     });
 }
@@ -199,7 +197,7 @@ void MonitorsGround::onRotateChanged()
 
 //当方向改变时 当分辨率改变时
 void MonitorsGround::onCurrentModeChanged()
-{
+{    
     onResize();
     if (m_setMergeMode || m_isSingleDisplay)
         return;
@@ -213,7 +211,7 @@ void MonitorsGround::onCurrentModeChanged()
           }
     }
 
-    executemultiScreenAlgo(false);
+   executemultiScreenAlgo(false);
 }
 
 
@@ -239,8 +237,6 @@ void MonitorsGround::executemultiScreenAlgo(const bool isRebound)
     updateConnectedState();
 
     //显示设置生效倒计时提示框
-    m_nEffectiveTime = isRebound ? 2 : 0;
-    m_effectiveTimer->setInterval(m_nEffectiveTime * 1000);
     Q_EMIT setEffectiveReminderVisible(true, m_nEffectiveTime);
     m_effectiveTimer->start();
 }
@@ -494,12 +490,8 @@ QPointF MonitorsGround::multiScreenSortAlgo(bool &isRestore, const bool isReboun
             QRectF rect = moveItemIntersect.intersected(m_lstSortItems[i]->mapRectToScene(m_lstSortItems[i]->boundingRect()));
             intersectedArea += rect.width()*rect.height();
 
-            qInfo() << "rect" << rect << "moveItemRect" << moveItemRect << "moveItemIntersect" << moveItemIntersect;
-
-            //1、移动块完全覆盖一个块 2、移动块与另外一个块十字相交时 执行自动回弹操作
-            if (moveItemRect.contains(m_lstSortItems[i]->mapRectToScene(m_lstSortItems[i]->boundingRect()))
-                    || (rect.top() < moveItemIntersect.top() && rect.bottom() > moveItemIntersect.bottom() && qFuzzyCompare(rect.left(), moveItemIntersect.left()) && qFuzzyCompare(rect.right(), moveItemIntersect.right()))
-                    || (rect.right() < moveItemIntersect.right() && rect.left() > moveItemIntersect.left() && qFuzzyCompare(rect.top(), moveItemIntersect.top()) && qFuzzyCompare(rect.bottom(), moveItemIntersect.bottom()))) {
+            //移动块完全覆盖一个块
+            if (moveItemRect.contains(m_lstSortItems[i]->mapRectToScene(m_lstSortItems[i]->boundingRect()))) {
                 lstShelterItems.append(m_lstSortItems[i]);
             }
 
@@ -1352,8 +1344,6 @@ void MonitorsGround::onRequestKeyPress(MonitorProxyWidget *pw, int keyValue)
     updateConnectedState();
     onResize();
 
-    m_nEffectiveTime = 2;
-    m_effectiveTimer->setInterval(m_nEffectiveTime * 1000);
     Q_EMIT setEffectiveReminderVisible(true, m_nEffectiveTime);
     m_effectiveTimer->start();
 }
@@ -1513,12 +1503,12 @@ void MonitorsGround::updateScale()
 
 void MonitorsGround::autoRebound()
 {
+
     for (auto pw : m_monitors.keys()) {
         //设置位置
         pw->setPos(pw->getPreCenter());
         pw->update();
     }
-    onResize();
 }
 
 //屏幕示意图平移居中
