@@ -18,7 +18,9 @@
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
+#ifndef DISABLE_AUTHENTICATION
 #include "modules/authentication/loginoptionsmodule.h"
+#endif
 #include "modules/accounts/accountsmodule.h"
 #include "modules/bluetooth/bluetoothmodule.h"
 #include "modules/commoninfo/commoninfomodule.h"
@@ -27,7 +29,9 @@
 #include "modules/keyboard/keyboardmodule.h"
 #include "modules/power/powermodule.h"
 #include "modules/sound/soundmodule.h"
+#ifndef DISABLE_SYS_UPDATE
 #include "modules/update/updatemodule.h"
+#endif
 #include "modules/mouse/mousemodule.h"
 #include "modules/wacom/wacommodule.h"
 #include "modules/display/displaymodule.h"
@@ -304,7 +308,6 @@ void MainWindow::setPrimaryScreen(QScreen *screen)
     m_primaryScreen = screen;
     updateWinsize();
     connect(m_primaryScreen, &QScreen::geometryChanged, this, &MainWindow::updateWinsize);
-    connect(m_primaryScreen, &QScreen::availableGeometryChanged, this, &MainWindow::updateWinsize);
 }
 
 void MainWindow::initAllModule(const QString &m)
@@ -313,7 +316,9 @@ void MainWindow::initAllModule(const QString &m)
         return;
 
     m_bInit = true;
+#ifndef DISABLE_AUTHENTICATION
     using namespace authentication;
+#endif
     using namespace sync;
     using namespace datetime;
     using namespace defapp;
@@ -325,7 +330,9 @@ void MainWindow::initAllModule(const QString &m)
     using namespace sound;
     using namespace personalization;
     using namespace power;
+#ifndef DISABLE_SYS_UPDATE
     using namespace update;
+#endif
     using namespace keyboard;
     using namespace wacom;
     using namespace systeminfo;
@@ -333,7 +340,9 @@ void MainWindow::initAllModule(const QString &m)
     using namespace notification;
 
     m_modules = {
+    #ifndef DISABLE_AUTHENTICATION
         { new LoginOptionsModule(this), tr("Biometric Authentication")},
+    #endif
         { new AccountsModule(this), tr("Accounts")},
         { new DisplayModule(this), tr("Display")},
         { new TouchscreenModule(this), tr("Touch Screen")},
@@ -347,7 +356,9 @@ void MainWindow::initAllModule(const QString &m)
         { new MouseModule(this), tr("Mouse")},
         { new WacomModule(this), tr("Drawing Tablet")},
         { new KeyboardModule(this), tr("Keyboard and Language")},
+#ifndef DISABLE_SYS_UPDATE
         { new UpdateModule(this), tr("Updates")},
+#endif
         { new SystemInfoModule(this), tr("System Info")},
         { new CommonInfoModule(this), tr("General Settings")},
     };
@@ -426,9 +437,6 @@ void MainWindow::updateWinsize(QRect rect)
     if (!qApp->screens().contains(m_primaryScreen))
         return;
 
-    if(this->isMaximized())
-        return;
-
     int w = m_primaryScreen->geometry().width();
     int h = m_primaryScreen->geometry().height();
     if (rect.width() && rect.height()) {
@@ -639,8 +647,6 @@ void MainWindow::setModuleSubscriptVisible(const QString &module, bool bIsDispla
             m_pair.first->setVisible(bIsDisplay);
             if (bIsDisplay) {
                 m_navModel->item(index, 0)->setData(QVariant::fromValue(QMargins(ActionIconSize + 15, 0, 0, 0)), Dtk::MarginsRole);
-                if(m_hideModuleNames.contains(module))
-                    m_navView->setRowHidden(index, true);
             } else {
                 m_navModel->item(index, 0)->setData(QVariant::fromValue(QMargins(0, 0, 0, 0)), Dtk::MarginsRole);
             }
@@ -1403,12 +1409,3 @@ QString MainWindow::moduleDisplayName(const QString &module) const
     }
     return find_it->second;
 }
-
-
-bool MainWindow::event(QEvent *event)
-{
-    if(event->type() == QEvent::Show || event->type() == QEvent::Hide ){
-        Q_EMIT mainwindowStateChange(event->type());
-    }
-    return DMainWindow::event(event);
-}
