@@ -29,6 +29,7 @@
 #include "modules/accounts/usermodel.h"
 #include "window/gsettingwatcher.h"
 #include "window/utils.h"
+#include "securityquestionspage.h"
 
 #include <DDialog>
 
@@ -111,6 +112,7 @@ void AccountsModule::active()
     });
     connect(m_accountsWidget, &AccountsWidget::requestLoadUserList, m_accountsWorker, &AccountsWorker::loadUserList);
     connect(m_accountsWidget, &AccountsWidget::requestUpdatGroupList, m_accountsWorker, &AccountsWorker::updateGroupinfo);
+    connect(m_accountsWorker, &AccountsWorker::showSafeyPage, m_accountsWidget, &AccountsWidget::onShowSafetyPage);
     m_frameProxy->pushWidget(this, m_accountsWidget);
     m_accountsWidget->setVisible(true);
     m_accountsWidget->showDefaultAccountInfo();
@@ -177,6 +179,7 @@ void AccountsModule::onShowAccountsDetailWidget(User *account)
     connect(m_userModel, &UserModel::deleteUserSuccess, w, &AccountsDetailWidget::requestBack);
     connect(m_userModel, &UserModel::isCancelChanged, w, &AccountsDetailWidget::resetDelButtonState);
     connect(w, &AccountsDetailWidget::requestShowPwdSettings, this, &AccountsModule::onShowPasswordPage);
+    connect(w, &AccountsDetailWidget::requestShowSecurityQuestionsSettings, this, &AccountsModule::onShowSecurityQuestionsPage);
     connect(w, &AccountsDetailWidget::requestSetAutoLogin, m_accountsWorker, &AccountsWorker::setAutoLogin);
     connect(w, &AccountsDetailWidget::requestSetAdministrator, m_accountsWorker, &AccountsWorker::setAdministrator);
     connect(w, &AccountsDetailWidget::requestNopasswdLogin, m_accountsWorker, &AccountsWorker::setNopasswdLogin);
@@ -198,7 +201,12 @@ void AccountsModule::onShowAccountsDetailWidget(User *account)
             w->onEditingFinished(false, userFullName);
         }
     });
+    connect(w, &AccountsDetailWidget::requestSecurityQuestionsCheck, m_accountsWorker, &AccountsWorker::asyncSecurityQuestionsCheck);
+
     m_frameProxy->pushWidget(this, w);
+    if (account->isCurrentUser()) {
+        Q_EMIT w->requestSecurityQuestionsCheck(account);
+    }
     w->setVisible(true);
     m_isCreatePage = false;
     //当前页面为用户详情页面的时候允许跳转默认帐户，否则只响应用户点击。避免出现显示了创建账户页面，又被账户详情页面隐藏的问题。
@@ -216,6 +224,7 @@ void AccountsModule::onShowCreateAccountPage()
     User *newUser = new User(this);
     w->setModel(m_userModel, newUser);
     connect(w, &CreateAccountPage::requestCreateUser, m_accountsWorker, &AccountsWorker::createAccount);
+    connect(w, &CreateAccountPage::requestCheckPwdLimitLevel, m_accountsWorker, &AccountsWorker::checkPwdLimitLevel);
     connect(m_accountsWorker, &AccountsWorker::accountCreationFinished, w, &CreateAccountPage::setCreationResult);
     connect(w, &CreateAccountPage::requestBack, m_accountsWidget, &AccountsWidget::handleRequestBack);
     m_frameProxy->pushWidget(this, w);
@@ -333,6 +342,8 @@ void AccountsModule::onShowPasswordPage(User *account)
     connect(w, &ModifyPasswdPage::requestUUID, m_accountsWorker, &AccountsWorker::getUUID);
     connect(w, &ModifyPasswdPage::requestLocalBindCheck, m_accountsWorker, &AccountsWorker::localBindCheck);
     connect(w, &ModifyPasswdPage::requestStartResetPasswordExec, m_accountsWorker, &AccountsWorker::startResetPasswordExec);
+    connect(w, &ModifyPasswdPage::requestSecurityQuestionsCheck, m_accountsWorker, &AccountsWorker::asyncSecurityQuestionsCheck);
+    connect(w, &ModifyPasswdPage::requestCheckPwdLimitLevel, m_accountsWorker, &AccountsWorker::checkPwdLimitLevel);
     connect(m_accountsWorker, &AccountsWorker::localBindUbid, w, &ModifyPasswdPage::onLocalBindCheckUbid);
     connect(m_accountsWorker, &AccountsWorker::localBindError, w, &ModifyPasswdPage::onLocalBindCheckError);
 
@@ -340,6 +351,20 @@ void AccountsModule::onShowPasswordPage(User *account)
     w->setVisible(true);
 }
 
+void AccountsModule::onShowSecurityQuestionsPage(User *account)
+{
+    SecurityQuestionsPage *w = new SecurityQuestionsPage(account);
+    w->setVisible(false);
+    connect(w, &SecurityQuestionsPage::requestBack, m_accountsWidget, &AccountsWidget::handleRequestBack);
+    connect(w, &SecurityQuestionsPage::requestSecurityQuestionsCheck, m_accountsWorker, &AccountsWorker::asyncSecurityQuestionsCheck);
+    connect(w, &SecurityQuestionsPage::requestSetSecurityQuestions, m_accountsWorker, &AccountsWorker::setSecurityQuestions);
+
+    m_frameProxy->pushWidget(this, w);
+    Q_EMIT w->requestSecurityQuestionsCheck(account);
+
+    w->setVisible(true);
+}
+
 void AccountsModule::onSetMainWindowEnabled(bool isEnabled)
 {
     if (m_pMainWindow)
