@@ -24,8 +24,6 @@
 #include "window/utils.h"
 #include "groupitem.h"
 #include "pwqualitymanager.h"
-#include "widgets/securitylevelitem.h"
-#include "securitylevelitembinder.h"
 
 #include <DFontSizeManager>
 #include <DDesktopServices>
@@ -193,14 +191,7 @@ void CreateAccountPage::initWidgets(QVBoxLayout *layout)
 
     QLabel *passwdLabel = new QLabel(tr("Password") + ':');
     m_passwdEdit->setAccessibleName("passwd_edit");
-    SecurityLevelItem *securityLevelItem  = new SecurityLevelItem(this);
-    SecurityLevelItemBinder::bind(securityLevelItem, m_passwdEdit);
-
-    QHBoxLayout *newPasswdLayout = new QHBoxLayout;
-    newPasswdLayout->addWidget(passwdLabel);
-    newPasswdLayout->addSpacing(80);
-    newPasswdLayout->addWidget(securityLevelItem);
-    layout->addLayout(newPasswdLayout);
+    layout->addWidget(passwdLabel);
     layout->addWidget(m_passwdEdit);
     layout->addSpacing(7);
 
@@ -275,8 +266,16 @@ void CreateAccountPage::initWidgets(QVBoxLayout *layout)
         }
     });
 
-    connect(m_fullnameEdit, &DLineEdit::editingFinished, this, [ = ]{
-        checkFullname();
+    connect(m_fullnameEdit, &DLineEdit::editingFinished, this, &CreateAccountPage::checkFullname);
+
+    //失焦后就提示
+    connect(m_passwdEdit, &DLineEdit::editingFinished, this, [ = ] {
+        PwqualityManager::ERROR_TYPE error = PwqualityManager::instance()->verifyPassword(m_nameEdit->lineEdit()->text(),
+                                                                                          m_passwdEdit->lineEdit()->text());
+        if (error != PwqualityManager::ERROR_TYPE::PW_NO_ERR) {
+            m_passwdEdit->setAlert(true);
+            m_passwdEdit->showAlertMessage(PwqualityManager::instance()->getErrorTips(error), m_passwdEdit, 2000);
+        }
     });
 
     //失焦后就提示，只检查密码一致性
@@ -287,6 +286,7 @@ void CreateAccountPage::initWidgets(QVBoxLayout *layout)
         }
     });
 
+
     connect(m_passwdEdit, &DPasswordEdit::textEdited, this, [ = ] {
         if (m_passwdEdit->isAlert()) {
             m_passwdEdit->hideAlertMessage();
@@ -378,27 +378,26 @@ void CreateAccountPage::showEvent(QShowEvent *event)
 
 void CreateAccountPage::createUser()
 {
-    bool checkResult = true;
+    bool check = false;
     //校验输入的用户名和密码
     if (!checkName()) {
-        checkResult = false;
+        check = true;
     }
 
-    if (!checkFullname(checkResult)) {
-        checkResult = false;
+    if (!checkFullname()) {
+        check = true;
     }
 
     bool needShowSafetyPage = false;
-    if (!checkPassword(m_repeatpasswdEdit, needShowSafetyPage, checkResult)) {
-        checkResult = false;
+    if (!checkPassword(m_repeatpasswdEdit, needShowSafetyPage)) {
+        check = true;
     }
 
-    if (!checkPassword(m_passwdEdit, needShowSafetyPage, checkResult)) {
-        checkResult = false;
+    if (!checkPassword(m_passwdEdit, needShowSafetyPage)) {
+        check = true;
     }
 
-
-    if (!checkResult) {
+    if (check) {
         if (needShowSafetyPage) {
             Q_EMIT requestCheckPwdLimitLevel();
         }
@@ -524,14 +523,13 @@ bool CreateAccountPage::checkName()
     return true;
 }
 
-bool CreateAccountPage::checkFullname(bool showTips)
+bool CreateAccountPage::checkFullname()
 {
     QString userFullName = m_fullnameEdit->lineEdit()->text();
 
     if (userFullName.size() > 32) {
         m_fullnameEdit->setAlert(true);
-        if(showTips)
-            m_fullnameEdit->showAlertMessage(tr("The full name is too long"), m_fullnameEdit, 2000);
+        m_fullnameEdit->showAlertMessage(tr("The full name is too long"), m_fullnameEdit, 2000);
         return false;
     }
 
@@ -539,11 +537,8 @@ bool CreateAccountPage::checkFullname(bool showTips)
     //vaild == false && code ==6 是用户名已存在
     if (!m_accountWorker->isUsernameValid(userFullName).argumentAt(0).toBool() && ErrCodeSystemUsed == m_accountWorker->isUsernameValid(userFullName).argumentAt(2).toInt()) {
         m_fullnameEdit->setAlert(true);
-        if(showTips){
-            m_fullnameEdit->showAlertMessage(tr("The full name has been used by other user accounts"), m_fullnameEdit, 2000);
-            m_fullnameEdit->lineEdit()->selectAll();
-        }
-
+        m_fullnameEdit->showAlertMessage(tr("The full name has been used by other user accounts"), m_fullnameEdit, 2000);
+        m_fullnameEdit->lineEdit()->selectAll();
         return false;
     }
 
@@ -553,11 +548,8 @@ bool CreateAccountPage::checkFullname(bool showTips)
         for (User *user : userList) {
             if (userFullName == user->fullname() || userFullName == user->name()) {
                 m_fullnameEdit->setAlert(true);
-                if(showTips){
-                    m_fullnameEdit->showAlertMessage(tr("The full name has been used by other user accounts"), m_fullnameEdit, 2000);
-                    m_fullnameEdit->lineEdit()->selectAll();
-                }
-
+                m_fullnameEdit->showAlertMessage(tr("The full name has been used by other user accounts"), m_fullnameEdit, 2000);
+                m_fullnameEdit->lineEdit()->selectAll();
                 return false;
             }
         }
@@ -565,11 +557,8 @@ bool CreateAccountPage::checkFullname(bool showTips)
         for (QString &group : groupList) {
             if (userFullName == group) {
                 m_fullnameEdit->setAlert(true);
-                if(showTips){
-                    m_fullnameEdit->showAlertMessage(tr("The full name has been used by other user accounts"), m_fullnameEdit, 2000);
-                    m_fullnameEdit->lineEdit()->selectAll();
-                }
-
+                m_fullnameEdit->showAlertMessage(tr("The full name has been used by other user accounts"), m_fullnameEdit, 2000);
+                m_fullnameEdit->lineEdit()->selectAll();
                 return false;
             }
         }
@@ -585,13 +574,12 @@ bool CreateAccountPage::checkFullname(bool showTips)
     return true;
 }
 
-bool CreateAccountPage::checkPassword(DPasswordEdit *edit, bool &needShowSafetyPage, bool showTips)
+bool CreateAccountPage::checkPassword(DPasswordEdit *edit, bool &needShowSafetyPage)
 {
     if (edit == m_repeatpasswdEdit) {
         if (m_passwdEdit->lineEdit()->text() != m_repeatpasswdEdit->lineEdit()->text()) {
             m_repeatpasswdEdit->setAlert(true);
-            if(showTips)
-                m_repeatpasswdEdit->showAlertMessage(tr("Passwords do not match"), this->parentWidget(), 2000);
+            m_repeatpasswdEdit->showAlertMessage(tr("Passwords do not match"), this->parentWidget(), 2000);
             return false;
         }
     }
@@ -601,8 +589,7 @@ bool CreateAccountPage::checkPassword(DPasswordEdit *edit, bool &needShowSafetyP
 
     if (error != PwqualityManager::ERROR_TYPE::PW_NO_ERR) {
         m_passwdEdit->setAlert(true);
-        if(showTips)
-            m_passwdEdit->showAlertMessage(PwqualityManager::instance()->getErrorTips(error), m_passwdEdit, 2000);
+        m_passwdEdit->showAlertMessage(PwqualityManager::instance()->getErrorTips(error), m_passwdEdit, 2000);
 
         // 企业版控制中心用户创建屏蔽安全中心登录安全的接口需求
         if ((DSysInfo::uosEditionType() == DSysInfo::UosEnterprise) || (DSysInfo::uosEditionType() == DSysInfo::UosEnterpriseC))
