@@ -48,10 +48,15 @@ class QVBoxLayout;
 class QHBoxLayout;
 class QPushButton;
 class QLabel;
-class QLocalServer;
-class QLocalSocket;
 QT_END_NAMESPACE
 
+
+namespace dcc {
+namespace widgets {
+class SecurityLevelItem;
+}
+}
+
 namespace DCC_NAMESPACE {
 namespace accounts {
 //修改密码页面
@@ -93,7 +98,6 @@ Q_SIGNALS:
 public Q_SLOTS:
     void onLocalBindCheckUbid(const QString &ubid);
     void onLocalBindCheckError(const QString &error);
-    void onNewConnection();
 
 private:
     dcc::accounts::User *m_curUser;
@@ -104,9 +108,8 @@ private:
     DTK_WIDGET_NAMESPACE::DLineEdit *m_passwordTipsEdit;
     bool m_isCurrent;
     bool m_isBindCheckError;
+    dcc::widgets::SecurityLevelItem *m_securityLevelItem;
     QTimer m_enableBtnTimer;
-    QLocalServer *m_localServer;
-    QLocalSocket *m_client;
 };
 }
 }
