@@ -308,7 +308,9 @@ void AdapterWidget::initConnect()
     connect(m_model, &BluetoothModel::displaySwitchChanged, m_showAnonymousCheckBox, &DCheckBox::setChecked);
     connect(m_showAnonymousCheckBox, &DCheckBox::stateChanged, this, [ = ](int state) {
         if (state == Qt::CheckState::Unchecked) {
-            Q_EMIT requestSetDisplaySwitch(false);
+            if (m_model->displaySwitch()) {
+                Q_EMIT requestSetDisplaySwitch(false);
+            }
             // 将蓝牙名称为空的设备过滤掉
             for (int i = 0; i < m_deviceLists.size(); i++) {
                 DeviceSettingsItem *pDeviceItem = m_deviceLists[i];
@@ -325,7 +327,9 @@ void AdapterWidget::initConnect()
                 }
             }
         } else {
-            Q_EMIT requestSetDisplaySwitch(true);
+            if (!m_model->displaySwitch()) {
+                Q_EMIT requestSetDisplaySwitch(true);
+            }
             // 显示所有蓝牙设备
             for (int i = 0; i < m_deviceLists.size(); i++) {
                 DeviceSettingsItem *pDeviceItem = m_deviceLists[i];
