@@ -49,8 +49,6 @@ DeveloperModeDialog::DeveloperModeDialog(QObject *parent)
     , m_importFile(new QFileDialog(this))
     , m_exportFile(new QFileDialog(this))
 {
-    setWindowFlags(Qt::WindowStaysOnTopHint | windowFlags());
-    setAttribute(Qt::WA_ShowModal, true);
     setAccessibleName("DeveloperModeDialog");
     setMinimumSize(QSize(350, 380));
     //总布局
@@ -273,7 +271,6 @@ void DeveloperModeDialog::setLogin()
         m_enterDev = true;
         btn->clearFocus();
         Q_EMIT requestLogin();
-        hide();
         connect(model, &CommonInfoModel::isLoginChenged, this, [requestDev, this](bool log) {
             if (!log || !m_enterDev)
                 return;
