@@ -23,7 +23,6 @@
 #define RESETPASSWORDDIALOG_H
 
 #include <QLocalSocket>
-#include <QLocalServer>
 #include <QStackedLayout>
 
 #include <DDialog>
@@ -80,7 +79,6 @@ public Q_SLOTS:
 
 private Q_SLOTS:
     void onReadFromServerChanged(int);
-    void onNewConnection();
 
 private:
     DButtonBox *m_buttonBox = nullptr;
@@ -96,8 +94,7 @@ private:
     QString m_appName;
     int m_fd;
     QTimer *m_monitorTimer;
-    QLocalSocket *m_client, *m_dccClient;
-    QLocalServer *m_localServer;
+    QLocalSocket *m_client;
     DDialog m_tipDialog;
     bool m_isClose;
     QStackedLayout *m_stackedLayout;
