@@ -1,5 +1,8 @@
 #include <QApplication>
 #include <gtest/gtest.h>
+#ifdef QT_DEBUG
+#include <sanitizer/asan_interface.h>
+#endif
 
 int main(int argc, char **argv)
 {
@@ -9,5 +12,11 @@ int main(int argc, char **argv)
 
     ::testing::InitGoogleTest(&argc, argv);
 
-    return  RUN_ALL_TESTS();
+    int ret = RUN_ALL_TESTS();
+
+#ifdef QT_DEBUG
+    __sanitizer_set_report_path("asan.log");
+#endif
+
+    return ret;
 }
