@@ -1,28 +1,28 @@
-<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="bg">
+<?xml version="1.0" ?><!DOCTYPE TS><TS language="bg" version="2.1">
 <context>
     <name>ReminderDialog</name>
     <message>
-        <location filename="../src/reboot-reminder-dialog/reminderdialog.cpp" line="35"/>
+        <location filename="../src/dialogs/reminderdialog.cpp" line="35"/>
         <source>Restart the computer to use the system and the applications properly</source>
         <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="../src/reboot-reminder-dialog/reminderdialog.cpp" line="36"/>
+        <location filename="../src/dialogs/reminderdialog.cpp" line="36"/>
         <source>Make sure all data had been saved first</source>
         <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="../src/reboot-reminder-dialog/reminderdialog.cpp" line="41"/>
+        <location filename="../src/dialogs/reminderdialog.cpp" line="45"/>
         <source>Cancel</source>
         <translation>Отказ</translation>
     </message>
     <message>
-        <location filename="../src/reboot-reminder-dialog/reminderdialog.cpp" line="41"/>
+        <location filename="../src/dialogs/reminderdialog.cpp" line="45"/>
         <source>Shut down</source>
         <translation>Изключване</translation>
     </message>
     <message>
-        <location filename="../src/reboot-reminder-dialog/reminderdialog.cpp" line="44"/>
+        <location filename="../src/dialogs/reminderdialog.cpp" line="48"/>
         <source>Reboot</source>
         <translation>Рестартиране</translation>
     </message>
