@@ -4,7 +4,7 @@
     <message>
         <location filename="../src/reboot-reminder-dialog/reminderdialog.cpp" line="35"/>
         <source>Restart the computer to use the system and the applications properly</source>
-        <translation>Pro správné fungování systému a aplikací, po provedení aktualizace počítač restartujte</translation>
+        <translation>Pro správné fungování systému a aplikací po provedení aktualizace počítač restartujte</translation>
     </message>
     <message>
         <location filename="../src/reboot-reminder-dialog/reminderdialog.cpp" line="36"/>
