@@ -299,7 +299,7 @@
     <message>
         <location filename="language.h" line="90"/>
         <source>कश्मीरी - (كشميري)</source>
-        <translation type="unfinished"/>
+        <translation>Cachemir - (Cachemira)</translation>
     </message>
     <message>
         <location filename="language.h" line="91"/>
@@ -439,7 +439,7 @@
     <message>
         <location filename="language.h" line="118"/>
         <source>Occitan</source>
-        <translation>Occitano </translation>
+        <translation>Occitano</translation>
     </message>
     <message>
         <location filename="language.h" line="119"/>
